from distutils.core import setup

setup(
  name = 'aa_mengjianing',
  version = '1.1.0',
  py_modules = ['aa_mengjianing'],
  author = 'hfpython',
  author_email = 'hfpython@headfirstlabs.com',
  url = 'http://www.headfirstlabs.com',
  description = 'A simple printer of nested list'
)